local mod = RW:Boss("Gunship Battle", "Icecrown Citadel", "Icecrown Citadel", "The Lower Spire")
local L

mod.BossIcon = [[Interface\Icons\achievement_dungeon_hordeairship]]

---------------------------
-- Variables
local tFightStart
local wBelow, tBelowCD
local wVeteran
local wJetPack
local wJump

---------------------------
-- Init
function mod:OnRegister()
	L = mod:RegisterLocale(self:GetName(), "enUS", true)
	if L then
		L.name = "Gunship Battle"
		
		--21:02] High Overlord Saurfang yells: The Alliance falter.
	
		if UnitFactionGroup("player") == "Horde" then
			L.YellPull = "Rise up, sons and daughters of the Horde! Today we battle a hated enemy! LOK'TAR OGAR!"
			L.YellWin = "The Alliance falter. Onward to the Lich King!"
			L.JumpTrigger = "We're taking hull damage, get a sorcerer out here to shut down those cannons!"
		else
			L.YellPull = "Fire up the engines! We got a meetin' with destiny, lads!"
			L.YellWin = "Don't say I didn't warn ya, scoundrels! Onward, brothers and sisters!"
		end
		
		L.fight_start = "Battle begins.."
		L.fight_start_opt = "Timer for when the battle starts"
		L.fight_start_group = "Fight Begin"
		
		L.health_frames = "Show stack frame for "..GetSpellInfo(72306)
		
		L.jetpack_check = "Put Goblin Rocket Pack on!"
		L.jetpack_check_opt = "Missing rocket pack warning"
		L.jetpack_check_group = "Goblin Rocket Pack"
		
		L.jump_warning = "Jump Over!"
		L.jump_warning_opt = "Warning when its time to jump over to the other ship"
	end
	L = mod:GetLocale()
	mod.L = L
	
	mod:SetTrigger(L.YellPull, 37215, 37540, 37200)

	if UnitFactionGroup("player") == "Horde" then
		mod:SetWin(L.YellWin)
	else
		mod:SetWin("combat")
	end
	
	mod:SetDelay(50)
	
	self:AddBoolOption("HealthFrame", L.health_frames, nil, nil, select(3, GetSpellInfo(72306)))
	
	tFightStart	= self:CustomTimer(45, L.fight_start, L.fight_start_opt, [[Interface\Icons\Achievement_WorldEvent_Valentine]], L.fight_start_group)
	tBelowCD	= self:CDTimer(37, 69705)
	
	wBelow		= self:CastWarning(69705)
	wJetPack	= self:CustomWarning(L.jetpack_check, L.jetpack_check_opt, [[Interface\Icons\ability_mount_rocketmount]], L.jetpack_check_group)
	wJump 		= self:CustomWarning(L.jump_warning, L.jump_warning_opt, 69705)
	
	iExp		= self:Icon("SKULL", 71188, false, nil, "CROSS", "SQUARE")
end

---------------------------
-- Locals
local furyStacks


local function updateStack()
	return furyStacks, 25
end

-- Jet pack cheeck
local function JetPackCheck()
	local shirt = GetInventoryItemLink("player", 4)
	if shirt then
		shirt = select(3, shirt:find("item:(%d+):"))
		if shirt ~= "49278" then
			wJetPack:Show()
		end
	end
end

---------------------------
-- Start

function mod:OnEngage(trigger)
	self:Track("Below", 69705)
	self:Track("Fury", 72306, 72307, 69638, 69637, 72308)
	
	-- TODO, add alliance mobID for the Below Zero casters
	self:DeathTrack("SourcererDeath", 37116)
	
	self:YellTrack("JumpTrigger", L.JumpTrigger)
	
	
	furyStacks = 0
	
	if self.db.profile.HealthFrame then
		self:SendMessage("RW_AddHealthFrame", updateStack, GetSpellInfo(72306), select(3, GetSpellInfo(72306)), "STACK")
	end
	
	if trigger then
		JetPackCheck()
	end
	
	tFightStart:Start()
end

function mod:Below(event, args)
	if event == "SPELL_CAST_SUCCESS" then
		wBelow:Show()
		self:SendMessage("RW_AddHealthFrame", mod:CUIDFromGUID(args.sGUID))
	
	elseif event == "SPELL_AURA_REMOVED" then
		tBelowCD:Start()
	end
end

function mod:Fury(event, args)
	if event == "SPELL_AURA_APPLIED" or event == "SPELL_AURA_APPLIED_DOSE" then
		furyStacks = args.amount or 1
	
	elseif event == "SPELL_AURA_REMOVED" then
		furyStacks = 0
	end
end

function mod:SourcererDeath(cID)
	self:SendMessage("RW_RemoveHealthFrame", cID)
end

function mod:JumpTrigger(event, msg, name)
	wJump:Show()
end